@@ -578,10 +578,15 @@ fn read(reader:&mut Reader,buffer:&mut Vec<u8>)->Result<Pointer,&'static str>{
     if buffer.len() > 0{
         reader.buffer.append(buffer);
     }
+
+    if !reader.flag.0{
+        unhandled::empty_counter(reader);
+    }
         
     //find flag
     if reader.flag.0 == false {
         // let start_flag_time = Instant::now();
+        // println!("reader.buffer_cursor : {:?}",reader.buffer_cursor);
         match vector_in_vector(&reader.buffer,&vec![0,1,0],reader.buffer_cursor){
             Ok(l)=>{
                 // println!("start_flag_time : {:?}",start_flag_time.elapsed());
@@ -599,10 +604,11 @@ fn read(reader:&mut Reader,buffer:&mut Vec<u8>)->Result<Pointer,&'static str>{
                 }
             },
             Err(_)=>{
+                
                 if reader.buffer.len() > 6{
                     reader.buffer_cursor = reader.buffer.len() - 5;
                 } else {
-                    reader.buffer_cursor = reader.buffer.len();
+                    reader.buffer_cursor = 0;
                 }
                 return Err("not_found-flag");
             }
